---
title: 쇼피파이(Shopify) 지원가능한 결제수단 목록
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 플러그인
tags:
  - 쇼피파이
  - 플러그인
  - 공통
searchTags:
  - 쇼피파이 지원
  - Shopify
  - 쇼피파이(Shopify)
  - 쇼피파이(Shopify) 지원가능목록
  - 쇼피파이
datetime: 2025-02-28T01:25:51.798Z
---

<Callout content=" &quot;Shopify(쇼피파이)&quot;에서 PortOne을 통해 다양한 결제수단을 지원하는 플러그인의 사용법을 안내드립니다.
쇼피파이 플러그인을 통하여 국내PG사와 해외PSP 이용이 가능합니다.

- **해외PSP만 이용하신 다면 글로벌 플랫폼만 이용하시면 되며,**
- **국내PG사까지 연동하시려면 PortOne 한국 플랫폼과 PortOne 글로벌 플랫폼을 모두 사용해야 합니다.** 

본 서비스는 서비스 이용 계약서 작성 후 이용이 가능하오니 쇼피파이 이용 안내 가이드를 참고 부탁드리며 
플러그인 연동은 쇼피파이 연동 가이드를 참고해 주세요." />

## 국내PG사와 결제 수단

- 포트원의 Shopify plugin을 통해 이용하실 수 있는 국내PG사와 결제 수단은 아래와 같습니다.

1. KAKAOPAY \
   \- 이용가능지역 : Korea \
   \- 결제수단 : 간편결제 일체
2. PAYCO\
   \- 이용가능지역 : Korea \
   \- 결제수단 : 간편결제 일체
3. TOSSPAY\
   \- 이용가능지역 : Korea \
   \- 결제수단 : 간편결제 일체
4. KG INICIS\
   \- 이용가능지역 : Korea \
   \- 결제수단 : 카드결제, NAVERPAY(허브형), KAKAOPAY(허브형), PAYCO(허브형), TOSSPAY(허브형)
5. NHN KCP \
   \- 이용가능지역 : Korea\
   \- 결제수단 : 카드결제, NAVERPAY(허브형), KAKAOPAY(허브형)
6. TOSS PAYMENTS\
   \- 이용가능지역 : Korea\
   \- 결제수단 : 카드결제, NAVERPAY(허브형), KAKAOPAY(허브형), 계좌이체
7. NICE PAYMENTS\
   \- 이용가능지역 : Korea\
   \- 결제수단 : 카드결제, NAVERPAY(허브형), KAKAOPAY(허브형),
8. PAYMENTWALL\
   \- 이용가능지역 : Global\
   \- 결제수단 : 카드결제, 간편결제
9. EXIMBAY\
   \- 이용가능지역 : Global\
   \- 결제수단 : 카드결제, Alipay+, WeChatPay, UnionPay\
   \- 이용가능지역 : Japan\
   \- 결제수단 : eContext(편의점결제)

10\. PAYLETTER\
\- 이용가능지역 : Global\
\- 결제수단 : 카드결제

## **글로벌 포트원에서 지원하는 해외PSP**

- 글로벌 포트원에서 지원하는 해외PSP 목록은 아래 링크에서 문서 목록을 참고해 주세요.

<Callout title="해외PSP 목록 보러가기 ↗" />

- [쇼피파이(Shopify) 이용가이드 보러가기 ↗](https://help.portone.io/content/shopify-guide)
- [쇼피파이(Shopify) 연동가이드 보러가기 ↗](https://developers.portone.io/opi/ko/extra/plugins/shopify/shopify/shopify-4?v=v1)
